@@ -75,7 +75,7 @@ else:
 
 bucket_name = 'ejgallo-lake-sales-dev'
 benchmark_acv_str = 'prophet/Data_Acquisition/source_data/Archive/2021/benchmark/data/acv_curves.csv'
-benchmark_geo_str = 's3://ejgallo-lake-sales-dev/prophet/Data_Acquisition/source_data/Archive/2021/benchmark/data/geo_codes.csv'
+benchmark_geo_str = 'prophet/Data_Acquisition/source_data/Archive/2021/benchmark/data/geo_codes.csv'
 brand_standards_str = 'prophet/Deployment/Auxillary_Functions/prime_directive/off_brand_standards_Q2.csv'
 upc_tier_str = 'prophet/Data_Acquisition/source_data/Archive/2021/benchmark/data//UPC_Tier_Dict.csv'
 
